==> qtjambi-webenginecore-6.2.2-sources.jar: io/qt/webengine/core/QWebEngineHistory.java <==
package io.qt.webengine.core;


/**
 * <p>Represents the history of a web engine page</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qwebenginehistory.html">QWebEngineHistory</a></p>
 */
public final class QWebEngineHistory extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineHistory.class);
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#back">QWebEngineHistory::back()</a></p>
     */
    @io.qt.QtUninvokable
    public final void back(){
        back_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void back_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#backItem">QWebEngineHistory::backItem()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem backItem(){
        return backItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem backItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#backItems">QWebEngineHistory::backItems(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> backItems(int maxItems){
        return backItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> backItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#backItemsModel">QWebEngineHistory::backItemsModel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="backItems")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryModel backItemsModel(){
        return backItemsModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryModel backItemsModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#canGoBack">QWebEngineHistory::canGoBack()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean canGoBack(){
        return canGoBack_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean canGoBack_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#canGoForward">QWebEngineHistory::canGoForward()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean canGoForward(){
        return canGoForward_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean canGoForward_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#clear">QWebEngineHistory::clear()</a></p>
     */
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#count">QWebEngineHistory::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#currentItem">QWebEngineHistory::currentItem()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem currentItem(){
        return currentItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem currentItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#currentItemIndex">QWebEngineHistory::currentItemIndex()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int currentItemIndex(){
        return currentItemIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int currentItemIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forward">QWebEngineHistory::forward()</a></p>
     */
    @io.qt.QtUninvokable
    public final void forward(){
        forward_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void forward_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forwardItem">QWebEngineHistory::forwardItem()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem forwardItem(){
        return forwardItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem forwardItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forwardItems">QWebEngineHistory::forwardItems(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> forwardItems(int maxItems){
        return forwardItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> forwardItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forwardItemsModel">QWebEngineHistory::forwardItemsModel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="forwardItems")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryModel forwardItemsModel(){
        return forwardItemsModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryModel forwardItemsModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#goToItem">QWebEngineHistory::goToItem(QWebEngineHistoryItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final void goToItem(io.qt.webengine.core.QWebEngineHistoryItem item){
        goToItem_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void goToItem_native_cref_QWebEngineHistoryItem(long __this__nativeId, long item);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#itemAt">QWebEngineHistory::itemAt(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem itemAt(int i){
        return itemAt_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), i);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem itemAt_native_int_constfct(long __this__nativeId, int i);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#items">QWebEngineHistory::items()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> items(){
        return items_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> items_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#itemsModel">QWebEngineHistory::itemsModel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="items")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryModel itemsModel(){
        return itemsModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryModel itemsModel_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public void writeTo(io.qt.core.QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @io.qt.QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    @io.qt.QtUninvokable
    public void readFrom(io.qt.core.QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @io.qt.QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineHistory(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-webenginecore-6.3.4-sources.jar: io/qt/webengine/core/QWebEngineHistory.java <==
package io.qt.webengine.core;


/**
 * <p>Represents the history of a web engine page</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qwebenginehistory.html">QWebEngineHistory</a></p>
 */
public final class QWebEngineHistory extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineHistory.class);
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#back">QWebEngineHistory::back()</a></p>
     */
    @io.qt.QtUninvokable
    public final void back(){
        back_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void back_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#backItem">QWebEngineHistory::backItem()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem backItem(){
        return backItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem backItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#backItems">QWebEngineHistory::backItems(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> backItems(int maxItems){
        return backItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> backItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#backItemsModel">QWebEngineHistory::backItemsModel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="backItems")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryModel backItemsModel(){
        return backItemsModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryModel backItemsModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#canGoBack">QWebEngineHistory::canGoBack()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean canGoBack(){
        return canGoBack_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean canGoBack_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#canGoForward">QWebEngineHistory::canGoForward()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean canGoForward(){
        return canGoForward_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean canGoForward_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#clear">QWebEngineHistory::clear()</a></p>
     */
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#count">QWebEngineHistory::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#currentItem">QWebEngineHistory::currentItem()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem currentItem(){
        return currentItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem currentItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#currentItemIndex">QWebEngineHistory::currentItemIndex()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int currentItemIndex(){
        return currentItemIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int currentItemIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forward">QWebEngineHistory::forward()</a></p>
     */
    @io.qt.QtUninvokable
    public final void forward(){
        forward_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void forward_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forwardItem">QWebEngineHistory::forwardItem()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem forwardItem(){
        return forwardItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem forwardItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forwardItems">QWebEngineHistory::forwardItems(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> forwardItems(int maxItems){
        return forwardItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> forwardItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#forwardItemsModel">QWebEngineHistory::forwardItemsModel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="forwardItems")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryModel forwardItemsModel(){
        return forwardItemsModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryModel forwardItemsModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#goToItem">QWebEngineHistory::goToItem(QWebEngineHistoryItem)</a></p>
     */
    @io.qt.QtUninvokable
    public final void goToItem(io.qt.webengine.core.QWebEngineHistoryItem item){
        goToItem_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void goToItem_native_cref_QWebEngineHistoryItem(long __this__nativeId, long item);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#itemAt">QWebEngineHistory::itemAt(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryItem itemAt(int i){
        return itemAt_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), i);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryItem itemAt_native_int_constfct(long __this__nativeId, int i);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#items">QWebEngineHistory::items()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> items(){
        return items_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.core.QWebEngineHistoryItem> items_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#itemsModel">QWebEngineHistory::itemsModel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="items")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineHistoryModel itemsModel(){
        return itemsModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.webengine.core.QWebEngineHistoryModel itemsModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#operator-lt-lt-1">QWebEngineHistory::operator&lt;&lt;(QDataStream&amp;,QWebEngineHistory)</a></p>
     */
    @io.qt.QtUninvokable
    public void writeTo(io.qt.core.QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @io.qt.QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginehistory.html#operator-gt-gt-1">QWebEngineHistory::operator&gt;&gt;(QDataStream&amp;,QWebEngineHistory&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public void readFrom(io.qt.core.QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @io.qt.QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineHistory(QPrivateConstructor p) { super(p); } 
    
}
